diff --git a/src/Mod/Fem/Gui/Command.cpp b/src/Mod/Fem/Gui/Command.cpp
index 4acec7859f..675aa19348 100644
--- a/src/Mod/Fem/Gui/Command.cpp
+++ b/src/Mod/Fem/Gui/Command.cpp
@@ -1446,7 +1446,7 @@ Gui::Action * CmdFemPostFunctions::createAction(void)
applyCommandData(this->className(), pcAction);
QAction* cmd0 = pcAction->addAction(QString());
- cmd0->setIcon(Gui::BitmapFactory().pixmap("fem-plane"));
+ cmd0->setIcon(Gui::BitmapFactory().pixmap("fem-post-geo-plane"));
QAction* cmd1 = pcAction->addAction(QString());
cmd1->setIcon(Gui::BitmapFactory().pixmap("fem-sphere"));
diff --git a/src/Mod/Fem/Gui/Resources/Fem.qrc b/src/Mod/Fem/Gui/Resources/Fem.qrc
index b1d6d45602..894136925c 100755
--- a/src/Mod/Fem/Gui/Resources/Fem.qrc
+++ b/src/Mod/Fem/Gui/Resources/Fem.qrc
@@ -66,7 +66,7 @@
icons/fem-post-geo-box.svg
icons/fem-post-geo-cylinder.svg
icons/fem-post-geo-isosurface.svg
- icons/fem-plane.svg
+ icons/fem-post-geo-plane.svg
icons/fem-purge-results.svg
icons/fem-result.svg
icons/fem-run-solver.svg
diff --git a/src/Mod/Fem/Gui/ViewProviderFemPostFunction.cpp b/src/Mod/Fem/Gui/ViewProviderFemPostFunction.cpp
index fb8baf41e3..fb68f5b906 100644
--- a/src/Mod/Fem/Gui/ViewProviderFemPostFunction.cpp
+++ b/src/Mod/Fem/Gui/ViewProviderFemPostFunction.cpp
@@ -322,7 +322,7 @@ PROPERTY_SOURCE(FemGui::ViewProviderFemPostPlaneFunction, FemGui::ViewProviderFe
ViewProviderFemPostPlaneFunction::ViewProviderFemPostPlaneFunction() {
- sPixmap = "fem-plane";
+ sPixmap = "fem-post-geo-plane";
setAutoScale(true);
diff --git a/src/Mod/Fem/Gui/Resources/icons/fem-plane.svg b/src/Mod/Fem/Gui/Resources/icons/fem-post-geo-plane.svg
similarity index 100%
rename from src/Mod/Fem/Gui/Resources/icons/fem-plane.svg
rename to src/Mod/Fem/Gui/Resources/icons/fem-post-geo-plane.svg
diff --git a/src/Mod/Fem/Gui/TaskPostBoxes.cpp b/src/Mod/Fem/Gui/TaskPostBoxes.cpp
index ffecd878e6..b094b3c2a3 100644
--- a/src/Mod/Fem/Gui/TaskPostBoxes.cpp
+++ b/src/Mod/Fem/Gui/TaskPostBoxes.cpp
@@ -388,8 +388,8 @@ void TaskPostDisplay::applyPythonCode() {
//############################################################################################
// ?
-// the icon fem-plane might be wrong but I do not know any better since the plane is one of the implicit functions
-TaskPostFunction::TaskPostFunction(ViewProviderDocumentObject* view, QWidget* parent): TaskPostBox(view, Gui::BitmapFactory().pixmap("fem-plane"), tr("Implicit function"), parent) {
+// the icon fem-post-geo-plane might be wrong but I do not know any better since the plane is one of the implicit functions
+TaskPostFunction::TaskPostFunction(ViewProviderDocumentObject* view, QWidget* parent): TaskPostBox(view, Gui::BitmapFactory().pixmap("fem-post-geo-plane"), tr("Implicit function"), parent) {
assert(view->isDerivedFrom(ViewProviderFemPostFunction::getClassTypeId()));